@@ -16,7 +16,11 @@ from typing import (
 import aiohttp
 import rasa.core
 from rasa.core.actions.constants import DEFAULT_SELECTIVE_DOMAIN, SELECTIVE_DOMAIN
-from rasa.core.constants import DEFAULT_REQUEST_TIMEOUT
+from rasa.core.constants import (
+    DEFAULT_REQUEST_TIMEOUT,
+    COMPRESS_ACTION_SERVER_REQUEST_ENV_NAME,
+    DEFAULT_COMPRESS_ACTION_SERVER_REQUEST,
+)
 from rasa.core.policies.policy import PolicyPrediction
 from rasa.nlu.constants import (
     RESPONSE_SELECTOR_DEFAULT_INTENT,
@@ -76,6 +80,7 @@ from rasa.shared.nlu.constants import (
 )
 from rasa.shared.utils.schemas.events import EVENTS_SCHEMA
 import rasa.shared.utils.io
+from rasa.utils.common import get_bool_env_variable
 from rasa.utils.endpoints import EndpointConfig, ClientResponseError
 
 if TYPE_CHECKING:
@@ -756,8 +761,17 @@ class RemoteAction(Action):
             logger.debug(
                 "Calling action endpoint to run action '{}'.".format(self.name())
             )
+
+            should_compress = get_bool_env_variable(
+                COMPRESS_ACTION_SERVER_REQUEST_ENV_NAME,
+                DEFAULT_COMPRESS_ACTION_SERVER_REQUEST,
+            )
+
             response: Any = await self.action_endpoint.request(
-                json=json_body, method="post", timeout=DEFAULT_REQUEST_TIMEOUT
+                json=json_body,
+                method="post",
+                timeout=DEFAULT_REQUEST_TIMEOUT,
+                compress=should_compress,
             )
 
             self._validate_action_result(response)
