@@ -1,26 +1,24 @@
+import asyncio
 import os
 import json
 import logging
+import threading
 from asyncio import AbstractEventLoop
 from typing import Any, Text, List, Optional, Union, Dict, TYPE_CHECKING
 import time
 
 from rasa.core.brokers.broker import EventBroker
+from rasa.core.exceptions import KafkaProducerInitializationError
 from rasa.shared.utils.io import DEFAULT_ENCODING
 from rasa.utils.endpoints import EndpointConfig
-from rasa.shared.exceptions import RasaException
 import rasa.shared.utils.common
 
 if TYPE_CHECKING:
-    from kafka import KafkaProducer
+    from confluent_kafka import KafkaError, Producer, Message
 
 logger = logging.getLogger(__name__)
 
 
-class KafkaProducerInitializationError(RasaException):
-    """Raised if the Kafka Producer cannot be properly initialized."""
-
-
 class KafkaEventBroker(EventBroker):
     """Kafka event broker."""
 
@@ -68,13 +66,11 @@ class KafkaEventBroker(EventBroker):
                 establish the certificate's authenticity.
             ssl_keyfile: Optional filename containing the client private key.
             ssl_check_hostname: Flag to configure whether ssl handshake
-                should verify that the certificate matches the brokers hostname.
+                should verify that the certificate matches the broker's hostname.
             security_protocol: Protocol used to communicate with brokers.
                 Valid values are: PLAINTEXT, SSL, SASL_PLAINTEXT, SASL_SSL.
         """
-        import kafka
-
-        self.producer: Optional[kafka.KafkaConsumer] = None
+        self.producer: Optional[Producer] = None
         self.url = url
         self.topic = topic
         self.client_id = client_id
@@ -86,7 +82,14 @@ class KafkaEventBroker(EventBroker):
         self.ssl_cafile = ssl_cafile
         self.ssl_certfile = ssl_certfile
         self.ssl_keyfile = ssl_keyfile
-        self.ssl_check_hostname = ssl_check_hostname
+        self.ssl_check_hostname = "https" if ssl_check_hostname else None
+
+        # Async producer implementation followed from confluent-kafka asyncio example:
+        # https://github.com/confluentinc/confluent-kafka-python/blob/master/examples/asyncio_example.py#L88  # noqa: W505, E501
+        self._loop = asyncio.get_event_loop()
+        self._cancelled = False
+        self._poll_thread = threading.Thread(target=self._poll_loop)
+        self._poll_thread.start()
 
     @classmethod
     async def from_endpoint_config(
@@ -107,12 +110,14 @@ class KafkaEventBroker(EventBroker):
         retry_delay_in_seconds: float = 5,
     ) -> None:
         """Publishes events."""
+        from confluent_kafka import KafkaException
+
         if self.producer is None:
             self.producer = self._create_producer()
-            connected = self.producer.bootstrap_connected()
-            if connected:
+            try:
+                self._check_kafka_connection()
                 logger.debug("Connection to kafka successful.")
-            else:
+            except KafkaException:
                 logger.debug("Failed to connect kafka.")
                 return
         while retries:
@@ -124,67 +129,82 @@ class KafkaEventBroker(EventBroker):
                     f"Could not publish message to kafka url '{self.url}'. "
                     f"Failed with error: {e}"
                 )
-                connected = self.producer.bootstrap_connected()
-                if not connected:
-                    self._close()
+                try:
+                    self._check_kafka_connection()
+                except KafkaException:
                     logger.debug("Connection to kafka lost, reconnecting...")
                     self.producer = self._create_producer()
-                    connected = self.producer.bootstrap_connected()
-                    if connected:
+                    try:
+                        self._check_kafka_connection()
                         logger.debug("Reconnection to kafka successful")
                         self._publish(event)
+                        return
+                    except KafkaException:
+                        pass
                 retries -= 1
                 time.sleep(retry_delay_in_seconds)
 
         logger.error("Failed to publish Kafka event.")
 
-    def _create_producer(self) -> "KafkaProducer":
-        import kafka
+    def _check_kafka_connection(self) -> None:
+        """Verifies connection with Kafka.
+
+        Raises:
+            KafkaException: if Kafka is disconnected.
+        """
+        if self.producer is not None:
+            self.producer.list_topics(timeout=5)
+
+    def _get_kafka_config(self) -> Dict[Text, Any]:
+        config = {
+            "client.id": self.client_id,
+            "bootstrap.servers": self.url,
+            "error_cb": kafka_error_callback,
+        }
 
         if self.security_protocol == "PLAINTEXT":
-            authentication_params = dict(
-                security_protocol=self.security_protocol, ssl_check_hostname=False
-            )
+            authentication_params: Dict[Text, Any] = {
+                "security.protocol": self.security_protocol,
+            }
         elif self.security_protocol == "SASL_PLAINTEXT":
-            authentication_params = dict(
-                sasl_plain_username=self.sasl_username,
-                sasl_plain_password=self.sasl_password,
-                sasl_mechanism=self.sasl_mechanism,
-                security_protocol=self.security_protocol,
-            )
+            authentication_params = {
+                "sasl.username": self.sasl_username,
+                "sasl.password": self.sasl_password,
+                "sasl.mechanism": self.sasl_mechanism,
+                "security.protocol": self.security_protocol,
+            }
         elif self.security_protocol == "SSL":
-            authentication_params = dict(
-                ssl_cafile=self.ssl_cafile,
-                ssl_certfile=self.ssl_certfile,
-                ssl_keyfile=self.ssl_keyfile,
-                ssl_check_hostname=False,
-                security_protocol=self.security_protocol,
-            )
+            authentication_params = {
+                "ssl.ca.location": self.ssl_cafile,
+                "ssl.certificate.location": self.ssl_certfile,
+                "ssl.key.location": self.ssl_keyfile,
+                "security.protocol": self.security_protocol,
+            }
         elif self.security_protocol == "SASL_SSL":
-            authentication_params = dict(
-                sasl_plain_username=self.sasl_username,
-                sasl_plain_password=self.sasl_password,
-                ssl_cafile=self.ssl_cafile,
-                ssl_certfile=self.ssl_certfile,
-                ssl_keyfile=self.ssl_keyfile,
-                ssl_check_hostname=self.ssl_check_hostname,
-                security_protocol=self.security_protocol,
-                sasl_mechanism=self.sasl_mechanism,
-            )
+            authentication_params = {
+                "sasl.username": self.sasl_username,
+                "sasl.password": self.sasl_password,
+                "ssl.ca.location": self.ssl_cafile,
+                "ssl.certificate.location": self.ssl_certfile,
+                "ssl.key.location": self.ssl_keyfile,
+                "ssl.endpoint.identification.algorithm": self.ssl_check_hostname,
+                "security.protocol": self.security_protocol,
+                "sasl.mechanism": self.sasl_mechanism,
+            }
         else:
             raise ValueError(
                 f"Cannot initialise `KafkaEventBroker`: "
                 f"Invalid `security_protocol` ('{self.security_protocol}')."
             )
 
+        return {**config, **authentication_params}
+
+    def _create_producer(self) -> "Producer":
+        import confluent_kafka
+
         try:
-            return kafka.KafkaProducer(
-                client_id=self.client_id,
-                bootstrap_servers=self.url,
-                value_serializer=lambda v: json.dumps(v).encode(DEFAULT_ENCODING),
-                **authentication_params,
-            )
-        except AssertionError as e:
+            return confluent_kafka.Producer(self._get_kafka_config())
+        except confluent_kafka.KafkaException as e:
             raise KafkaProducerInitializationError(
                 f"Cannot initialise `KafkaEventBroker`: {e}"
             )
@@ -209,16 +229,68 @@ class KafkaEventBroker(EventBroker):
             f" key={partition_key!s}, headers={headers})"
         )
 
+        serialized_event = json.dumps(event).encode(DEFAULT_ENCODING)
+
         if self.producer is not None:
-            self.producer.send(
-                self.topic, value=event, key=partition_key, headers=headers
+            self.producer.produce(
+                self.topic,
+                value=serialized_event,
+                key=partition_key,
+                headers=headers,
+                on_delivery=delivery_report,
             )
 
     def _close(self) -> None:
-        if self.producer is not None:
-            self.producer.close()
+        self._cancelled = True
+        self._poll_thread.join()
 
     @rasa.shared.utils.common.lazy_property
     def rasa_environment(self) -> Optional[Text]:
         """Get value of the `RASA_ENVIRONMENT` environment variable."""
         return os.environ.get("RASA_ENVIRONMENT", "RASA_ENVIRONMENT_NOT_SET")
+
+    def _poll_loop(self) -> None:
+        """Polls the producer for events.
+
+        Required to trigger the on_delivery callback passed to produce method.
+        """
+        if self.producer is not None:
+            while not self._cancelled:
+                self.producer.poll(0.1)
+
+
+def kafka_error_callback(err: "KafkaError") -> None:
+    """Callback for Kafka errors.
+
+    Any exception raised from this callback will be re-raised from the
+    triggering flush() call.
+    """
+    from confluent_kafka import KafkaException, KafkaError
+
+    # handle authentication / connection related issues, likely pointing
+    # to a configuration error
+    if (
+        err.code() == KafkaError._ALL_BROKERS_DOWN
+        or err.code() == KafkaError._AUTHENTICATION
+        or err.code() == KafkaError._MAX_POLL_EXCEEDED
+    ):
+        raise KafkaException(err)
+    else:
+        logger.warning("A KafkaError has been raised.", exc_info=True)
+
+
+def delivery_report(err: Exception, msg: "Message") -> None:
+    """Reports the failure or success of a message delivery.
+
+    Args:
+        err (KafkaError): The error that occurred on None on success.
+        msg (Message): The message that was produced or failed.
+    """
+    if err is not None:
+        logger.error(f"Delivery failed for User record {msg.key()}: {err}")
+        return
+
+    logger.info(
+        f"User record {msg.key()} successfully produced to "
+        f"{msg.topic()} [{msg.partition()}] at offset {msg.offset()}."
+    )
