@@ -51,7 +51,9 @@ def _create_from_endpoint_config(
         from rasa.core.nlg import TemplatedNaturalLanguageGenerator
 
         # this is the default type if no endpoint config is set
-        nlg = TemplatedNaturalLanguageGenerator(domain.responses)
+        nlg: "NaturalLanguageGenerator" = TemplatedNaturalLanguageGenerator(
+            domain.responses
+        )
     elif endpoint_config.type is None or endpoint_config.type.lower() == "callback":
         from rasa.core.nlg import CallbackNaturalLanguageGenerator
 
