@@ -14,6 +14,7 @@ from transformers import (  # noqa: F401, E402
     # TFXLMModel,
     TFDistilBertModel,
     TFRobertaModel,
+    TFCamembertModel,
     PreTrainedTokenizer,
     BertTokenizer,
     OpenAIGPTTokenizer,
@@ -22,6 +23,7 @@ from transformers import (  # noqa: F401, E402
     # XLMTokenizer,
     DistilBertTokenizer,
     RobertaTokenizer,
+    CamembertTokenizer,
 )
 from rasa.nlu.utils.hugging_face.transformers_pre_post_processors import (  # noqa: F401, E402, E501
     bert_tokens_pre_processor,
@@ -36,6 +38,7 @@ from rasa.nlu.utils.hugging_face.transformers_pre_post_processors import (  # no
     openaigpt_tokens_cleaner,
     gpt2_tokens_cleaner,
     xlnet_tokens_cleaner,
+    camembert_tokens_pre_processor,
 )
 
 
@@ -48,6 +51,7 @@ model_class_dict: Dict[Text, Type[TFPreTrainedModel]] = {
     # library https://github.com/huggingface/transformers/issues/2729
     "distilbert": TFDistilBertModel,
     "roberta": TFRobertaModel,
+    "camembert": TFCamembertModel,
 }
 model_tokenizer_dict: Dict[Text, Type[PreTrainedTokenizer]] = {
     "bert": BertTokenizer,
@@ -57,6 +61,7 @@ model_tokenizer_dict: Dict[Text, Type[PreTrainedTokenizer]] = {
     # "xlm": XLMTokenizer,
     "distilbert": DistilBertTokenizer,
     "roberta": RobertaTokenizer,
+    "camembert": CamembertTokenizer,
 }
 model_weights_defaults = {
     "bert": "rasa/LaBSE",
@@ -66,6 +71,7 @@ model_weights_defaults = {
     # "xlm": "xlm-mlm-enfr-1024",
     "distilbert": "distilbert-base-uncased",
     "roberta": "roberta-base",
+    "camembert": "camembert-base",
 }
 
 model_special_tokens_pre_processors = {
@@ -76,6 +82,7 @@ model_special_tokens_pre_processors = {
     # "xlm": xlm_tokens_pre_processor,
     "distilbert": bert_tokens_pre_processor,
     "roberta": roberta_tokens_pre_processor,
+    "camembert": camembert_tokens_pre_processor,
 }
 
 model_tokens_cleaners = {
@@ -86,6 +93,7 @@ model_tokens_cleaners = {
     # "xlm": xlm_tokens_pre_processor,
     "distilbert": bert_tokens_cleaner,  # uses the same as BERT
     "roberta": gpt2_tokens_cleaner,  # Uses the same as GPT2
+    "camembert": xlnet_tokens_cleaner,  # Removing underscores _
 }
 
 model_embeddings_post_processors = {
@@ -96,4 +104,5 @@ model_embeddings_post_processors = {
     # "xlm": xlm_embeddings_post_processor,
     "distilbert": bert_embeddings_post_processor,
     "roberta": roberta_embeddings_post_processor,
+    "camembert": roberta_embeddings_post_processor,
 }
