@@ -7,6 +7,7 @@ import tensorflow as tf
 from keras.utils.control_flow_util import smart_cond
 from tensorflow.keras import backend as K
 
+import rasa.shared.utils.cli
 from rasa.utils.tensorflow.layers import RandomlyConnectedDense
 
 
@@ -47,9 +48,9 @@ class MultiHeadAttention(tf.keras.layers.Layer):
         super().__init__()
 
         if units % num_heads != 0:
-            raise ValueError(
-                f"number of units {units} should be proportional to "
-                f"number of attention heads {num_heads}."
+            rasa.shared.utils.cli.print_error_and_exit(
+                f"Value Error: The given transformer size {units} should be a "
+                f"multiple of the number of attention heads {num_heads}."
             )
 
         self.num_heads = num_heads
